==> blue_cemetery-3.215.1.tar.gz: blue_cemetery-3.215.1/README.md <==
# 🪦 blue-cemetery

🌀 `@cemetery` is the cemetery for [`abcli`](https://github.com/kamangir/awesome-bash-cli) experiments.

```bash
pip install blue-plugin
```

|   |   |   |
| --- | --- | --- |
| [`sagesemseg`](#) [![image](https://github.com/kamangir/assets/blob/main/blue-sandbox/sagesemseg-predict.png?raw=true)](./blue_sandbox/sagesemseg/README.md) A SemSeg (Semantic Segmenter) trained and deployed on AWS Sagemaker. | [``@damages``](#) [![image](https://github.com/kamangir/assets/raw/main/blue-sandbox/Maui-Hawaii-fires-Aug-23-ingest-2025-01-10-qqJqhm.png?raw=true)](./blue_sandbox/microsoft_building_damage_assessment/README.md) Satellite imagery damage assessment workflow | [`VisuaLyze`](#) [![image](https://github.com/kamangir/openai-commands/assets/1007567/7c0ed5f7-6941-451c-a17e-504c6adab23f)](./blue_sandbox/VisuaLyze) How about calling it "VisuaLyze"? ... - OpenAI |
| [`gpt`](#) [![image](https://github.com/kamangir/assets/raw/main/blue-cemetery/marquee.png?raw=true)](./blue_sandbox/cemetery/gpt) co-authored with ChapGPT. | [`code generation`](#) [![image](https://github.com/kamangir/openai-commands/blob/main/assets/completion_i2i_function.png?raw=true)](./blue_sandbox/cemetery/code_generation)  | [`template`](#) [![image](https://github.com/kamangir/assets/raw/main/blue-cemetery/marquee.png?raw=true)]()  |

---


[![pylint](https://github.com/kamangir/blue-cemetery/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/blue-cemetery/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/blue-cemetery/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/blue-cemetery/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/blue-cemetery/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/blue-cemetery/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/blue-cemetery.svg)](https://pypi.org/project/blue-cemetery/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blue-cemetery)](https://pypistats.org/packages/blue-cemetery)

built by 🌀 [`blue_options-4.202.1`](https://github.com/kamangir/awesome-bash-cli), based on 🪦 [`blue_cemetery-3.215.1`](https://github.com/kamangir/blue-cemetery).

==> blue_cemetery-3.216.1.tar.gz: blue_cemetery-3.216.1/README.md <==
# 🪦 blue-cemetery

🪦 `@cemetery` is the cemetery for [`abcli`](https://github.com/kamangir/awesome-bash-cli) experiments.

```bash
pip install blue-cemetery
```

|   |   |   |
| --- | --- | --- |
| [`sagesemseg`](#) [![image](https://github.com/kamangir/assets/blob/main/blue-sandbox/sagesemseg-predict.png?raw=true)](./blue_sandbox/sagesemseg/README.md) A SemSeg (Semantic Segmenter) trained and deployed on AWS Sagemaker. | [``@damages``](#) [![image](https://github.com/kamangir/assets/raw/main/blue-sandbox/Maui-Hawaii-fires-Aug-23-ingest-2025-01-10-qqJqhm.png?raw=true)](./blue_sandbox/microsoft_building_damage_assessment/README.md) Satellite imagery damage assessment workflow | [`VisuaLyze`](#) [![image](https://github.com/kamangir/openai-commands/assets/1007567/7c0ed5f7-6941-451c-a17e-504c6adab23f)](./blue_sandbox/VisuaLyze) How about calling it "VisuaLyze"? ... - OpenAI |
| [`gpt`](#) [![image](https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true)](./blue_sandbox/cemetery/gpt) co-authored with ChapGPT. | [`code generation`](#) [![image](https://github.com/kamangir/openai-commands/blob/main/assets/completion_i2i_function.png?raw=true)](./blue_sandbox/cemetery/code_generation)  | [`template`](#) [![image](https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true)]()  |

---


[![pylint](https://github.com/kamangir/blue-cemetery/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/blue-cemetery/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/blue-cemetery/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/blue-cemetery/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/blue-cemetery/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/blue-cemetery/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/blue-cemetery.svg)](https://pypi.org/project/blue-cemetery/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blue-cemetery)](https://pypistats.org/packages/blue-cemetery)

built by 🌀 [`blue_options-4.202.1`](https://github.com/kamangir/awesome-bash-cli), based on 🪦 [`blue_cemetery-3.216.1`](https://github.com/kamangir/blue-cemetery).
